Learn R Programming

mlbgameday (version 0.2.0)

pitch_count: Internal function to calculate balls and strikes for an atbat.

Description

Internal function to calculate balls and strikes for an atbat.

Usage

pitch_count(dat)

Arguments

dat

A pitch table

...

additional arguments.